==> aws_cdk.aws_kinesis-1.147.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesis_StreamEncryption(p) {
}
function _aws_cdk_aws_kinesis_StreamMode(p) {
}
function _aws_cdk_aws_kinesis_CfnStreamConsumerProps(p) {
}
function _aws_cdk_aws_kinesis_StreamAttributes(p) {
}
function _aws_cdk_aws_kinesis_CfnStreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.streamEncryption))
        _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty(p.streamEncryption);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesis_CfnStreamConsumer(p) {
}
function _aws_cdk_aws_kinesis_StreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.encryption))
        _aws_cdk_aws_kinesis_StreamEncryption(p.encryption);
    if (!visitedObjects.has(p.streamMode))
        _aws_cdk_aws_kinesis_StreamMode(p.streamMode);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesis_CfnStream(p) {
}
function _aws_cdk_aws_kinesis_CfnStream_StreamModeDetailsProperty(p) {
}
function _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty(p) {
}
function _aws_cdk_aws_kinesis_IStream(p) {
}
function _aws_cdk_aws_kinesis_Stream(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesis_StreamEncryption, _aws_cdk_aws_kinesis_StreamMode, _aws_cdk_aws_kinesis_CfnStreamConsumerProps, _aws_cdk_aws_kinesis_StreamAttributes, _aws_cdk_aws_kinesis_CfnStreamProps, _aws_cdk_aws_kinesis_CfnStreamConsumer, _aws_cdk_aws_kinesis_StreamProps, _aws_cdk_aws_kinesis_CfnStream, _aws_cdk_aws_kinesis_CfnStream_StreamModeDetailsProperty, _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty, _aws_cdk_aws_kinesis_IStream, _aws_cdk_aws_kinesis_Stream };
module.exports.DeprecationError = DeprecationError;

==> aws_cdk.aws_kinesis-1.152.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesis_StreamEncryption(p) {
}
function _aws_cdk_aws_kinesis_StreamMode(p) {
}
function _aws_cdk_aws_kinesis_CfnStreamConsumerProps(p) {
}
function _aws_cdk_aws_kinesis_StreamAttributes(p) {
}
function _aws_cdk_aws_kinesis_CfnStreamConsumer(p) {
}
function _aws_cdk_aws_kinesis_CfnStreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.streamEncryption))
        _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty(p.streamEncryption);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesis_StreamProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.encryption))
        _aws_cdk_aws_kinesis_StreamEncryption(p.encryption);
    if (!visitedObjects.has(p.streamMode))
        _aws_cdk_aws_kinesis_StreamMode(p.streamMode);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesis_CfnStream(p) {
}
function _aws_cdk_aws_kinesis_CfnStream_StreamModeDetailsProperty(p) {
}
function _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty(p) {
}
function _aws_cdk_aws_kinesis_IStream(p) {
}
function _aws_cdk_aws_kinesis_Stream(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesis_StreamEncryption, _aws_cdk_aws_kinesis_StreamMode, _aws_cdk_aws_kinesis_CfnStreamConsumerProps, _aws_cdk_aws_kinesis_StreamAttributes, _aws_cdk_aws_kinesis_CfnStreamConsumer, _aws_cdk_aws_kinesis_CfnStreamProps, _aws_cdk_aws_kinesis_StreamProps, _aws_cdk_aws_kinesis_CfnStream, _aws_cdk_aws_kinesis_CfnStream_StreamModeDetailsProperty, _aws_cdk_aws_kinesis_CfnStream_StreamEncryptionProperty, _aws_cdk_aws_kinesis_IStream, _aws_cdk_aws_kinesis_Stream };
module.exports.DeprecationError = DeprecationError;
